@@ -39,8 +39,9 @@ NewDialog::NewDialog(QWidget *parent) :
     width_px = 1024;
     height_px = 768;
     imageRatio = (width_px/height_px);
-    currentUnit = PX;
+    currentUnit = SETTINGS->getUnit();
     ui->imageResCombo->setCurrentIndex(PPI);
+    ui->imageWHcombo->setCurrentIndex(currentUnit);
     //Standard ppi
     ui->imageRvalue->setValue(96.0);
     ui->pixelWvalue->setValue(width_px);
@@ -222,7 +223,8 @@ void NewDialog::on_imageRvalue_valueChanged(double value)
 
 void NewDialog::on_imageHvalue_valueChanged(double value)
 {
-    Q_UNUSED(value)
+    Q_UNUSED(value);
+    imageRatio = (width_px/height_px);
     float resoulution_in = ui->imageRvalue->value();
     if(ui->imageResCombo->currentIndex() == PPM)
         resoulution_in = resoulution_in * CM_IN_INCH;
@@ -248,15 +250,12 @@ void NewDialog::on_imageHvalue_valueChanged(double value)
         if(ui->imageHvalue->hasFocus())
             ui->imageWvalue->setValue(ui->imageHvalue->value() * imageRatio); //width = height * imageRatio
     }
-    else
-    {
-        imageRatio = (width_px/height_px);
-    }
 }
 
 void NewDialog::on_imageWvalue_valueChanged(double value)
 {
-    Q_UNUSED(value)
+    Q_UNUSED(value);
+    imageRatio = (width_px/height_px);
     float resoulution_in = ui->imageRvalue->value();
     if(ui->imageResCombo->currentIndex() == PPM)
         resoulution_in = resoulution_in * CM_IN_INCH;
@@ -280,10 +279,6 @@ void NewDialog::on_imageWvalue_valueChanged(double value)
         if(ui->imageWvalue->hasFocus())
             ui->imageHvalue->setValue(ui->imageWvalue->value() / imageRatio); //height = width / imageRatio
     }
-    else
-    {
-        imageRatio = (width_px/height_px);
-    }
 }
 
 void NewDialog::setMode(Mode mode)
