@@ -19,6 +19,7 @@ aboutDialog::aboutDialog(QWidget *parent) :
     ui->creditsTextArea->setVisible(false);
     ui->creditsTextArea->setText(tr("<b>Developers</b>"
                                     "<br>Commercial - ICS<br>Lead - Dylan Coakley"
+                                    "<br>Developer - Marek Mosna"
                                     "<br>Developer - Dmitry Vasilenko"
                                     "<br><br><b>Graphics</b>"
                                     "<br>Main icon - Robert BM"
@@ -35,15 +36,15 @@ aboutDialog::aboutDialog(QWidget *parent) :
                                     "<br>Michael Sheppard - Code"
                                     "<br>Helene Levernieux - Project Icon"
                                     "<br><br><b>Translators</b>"
-                                    "<br>FR - Ludovic"
-                                    "<br>FR - Nerdouille"
-                                    "<br>NL - Freek"
+                                    "<br>FR - Ludovic, Nerdouille"
+                                    "<br>NL - Freek Pol"
                                     "<br>DE - Freacore"
                                     "<br>zh_TW - Coolshou"
                                     "<br><br><b>Special thanks"
                                     "</b><br>I would like to thank Samantha for being an absolute gem of a person. You light up my life and I'm so glad to have found you."));
 
-    ui->appName->setText(qApp->applicationName());
+    QString appName = qApp->applicationName().replace("p","P");
+    ui->appName->setText(appName);
     QFont font;
     font.setPointSize(14);
     ui->appName->setFont(font);
